# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PermitStatusUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'internal_user_identifier': 'str',
        'internal_user_name': 'str',
        'permit_status': 'PermitStatus',
        'additional_comments': 'str',
        'permit_cancellation_reason': 'AllOfPermitStatusUpdateRequestPermitCancellationReason',
        'permit_cancellation_reason_other': 'str'
    }

    attribute_map = {
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name',
        'permit_status': 'permit_status',
        'additional_comments': 'additional_comments',
        'permit_cancellation_reason': 'permit_cancellation_reason',
        'permit_cancellation_reason_other': 'permit_cancellation_reason_other'
    }

    def __init__(self, internal_user_identifier=None, internal_user_name=None, permit_status=None, additional_comments=None, permit_cancellation_reason=None, permit_cancellation_reason_other=None):  # noqa: E501
        """PermitStatusUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._internal_user_identifier = None
        self._internal_user_name = None
        self._permit_status = None
        self._additional_comments = None
        self._permit_cancellation_reason = None
        self._permit_cancellation_reason_other = None
        self.discriminator = None
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name
        self.permit_status = permit_status
        if additional_comments is not None:
            self.additional_comments = additional_comments
        if permit_cancellation_reason is not None:
            self.permit_cancellation_reason = permit_cancellation_reason
        if permit_cancellation_reason_other is not None:
            self.permit_cancellation_reason_other = permit_cancellation_reason_other

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this PermitStatusUpdateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_identifier of this PermitStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this PermitStatusUpdateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_identifier: The internal_user_identifier of this PermitStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this PermitStatusUpdateRequest.  # noqa: E501

        Max length 100 characters  # noqa: E501

        :return: The internal_user_name of this PermitStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this PermitStatusUpdateRequest.

        Max length 100 characters  # noqa: E501

        :param internal_user_name: The internal_user_name of this PermitStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    @property
    def permit_status(self):
        """Gets the permit_status of this PermitStatusUpdateRequest.  # noqa: E501


        :return: The permit_status of this PermitStatusUpdateRequest.  # noqa: E501
        :rtype: PermitStatus
        """
        return self._permit_status

    @permit_status.setter
    def permit_status(self, permit_status):
        """Sets the permit_status of this PermitStatusUpdateRequest.


        :param permit_status: The permit_status of this PermitStatusUpdateRequest.  # noqa: E501
        :type: PermitStatus
        """
        if permit_status is None:
            raise ValueError("Invalid value for `permit_status`, must not be `None`")  # noqa: E501

        self._permit_status = permit_status

    @property
    def additional_comments(self):
        """Gets the additional_comments of this PermitStatusUpdateRequest.  # noqa: E501

        Required if permit_status = refused Max length 500 characters  # noqa: E501

        :return: The additional_comments of this PermitStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._additional_comments

    @additional_comments.setter
    def additional_comments(self, additional_comments):
        """Sets the additional_comments of this PermitStatusUpdateRequest.

        Required if permit_status = refused Max length 500 characters  # noqa: E501

        :param additional_comments: The additional_comments of this PermitStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._additional_comments = additional_comments

    @property
    def permit_cancellation_reason(self):
        """Gets the permit_cancellation_reason of this PermitStatusUpdateRequest.  # noqa: E501


        :return: The permit_cancellation_reason of this PermitStatusUpdateRequest.  # noqa: E501
        :rtype: AllOfPermitStatusUpdateRequestPermitCancellationReason
        """
        return self._permit_cancellation_reason

    @permit_cancellation_reason.setter
    def permit_cancellation_reason(self, permit_cancellation_reason):
        """Sets the permit_cancellation_reason of this PermitStatusUpdateRequest.


        :param permit_cancellation_reason: The permit_cancellation_reason of this PermitStatusUpdateRequest.  # noqa: E501
        :type: AllOfPermitStatusUpdateRequestPermitCancellationReason
        """

        self._permit_cancellation_reason = permit_cancellation_reason

    @property
    def permit_cancellation_reason_other(self):
        """Gets the permit_cancellation_reason_other of this PermitStatusUpdateRequest.  # noqa: E501

        Required if permit_cancellation_reason is other  # noqa: E501

        :return: The permit_cancellation_reason_other of this PermitStatusUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._permit_cancellation_reason_other

    @permit_cancellation_reason_other.setter
    def permit_cancellation_reason_other(self, permit_cancellation_reason_other):
        """Sets the permit_cancellation_reason_other of this PermitStatusUpdateRequest.

        Required if permit_cancellation_reason is other  # noqa: E501

        :param permit_cancellation_reason_other: The permit_cancellation_reason_other of this PermitStatusUpdateRequest.  # noqa: E501
        :type: str
        """

        self._permit_cancellation_reason_other = permit_cancellation_reason_other

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PermitStatusUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PermitStatusUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PermitAlterationSummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'permit_alteration_reference_number': 'str',
        'date_created': 'datetime',
        'deadline_date': 'datetime',
        'alteration_status': 'AlterationStatusResponse',
        'alteration_status_string': 'str',
        'alteration_type': 'AlterationTypeResponse',
        'alteration_type_string': 'str'
    }

    attribute_map = {
        'permit_alteration_reference_number': 'permit_alteration_reference_number',
        'date_created': 'date_created',
        'deadline_date': 'deadline_date',
        'alteration_status': 'alteration_status',
        'alteration_status_string': 'alteration_status_string',
        'alteration_type': 'alteration_type',
        'alteration_type_string': 'alteration_type_string'
    }

    def __init__(self, permit_alteration_reference_number=None, date_created=None, deadline_date=None, alteration_status=None, alteration_status_string=None, alteration_type=None, alteration_type_string=None):  # noqa: E501
        """PermitAlterationSummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._permit_alteration_reference_number = None
        self._date_created = None
        self._deadline_date = None
        self._alteration_status = None
        self._alteration_status_string = None
        self._alteration_type = None
        self._alteration_type_string = None
        self.discriminator = None
        self.permit_alteration_reference_number = permit_alteration_reference_number
        self.date_created = date_created
        self.deadline_date = deadline_date
        self.alteration_status = alteration_status
        self.alteration_status_string = alteration_status_string
        self.alteration_type = alteration_type
        self.alteration_type_string = alteration_type_string

    @property
    def permit_alteration_reference_number(self):
        """Gets the permit_alteration_reference_number of this PermitAlterationSummaryResponse.  # noqa: E501


        :return: The permit_alteration_reference_number of this PermitAlterationSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._permit_alteration_reference_number

    @permit_alteration_reference_number.setter
    def permit_alteration_reference_number(self, permit_alteration_reference_number):
        """Sets the permit_alteration_reference_number of this PermitAlterationSummaryResponse.


        :param permit_alteration_reference_number: The permit_alteration_reference_number of this PermitAlterationSummaryResponse.  # noqa: E501
        :type: str
        """
        if permit_alteration_reference_number is None:
            raise ValueError("Invalid value for `permit_alteration_reference_number`, must not be `None`")  # noqa: E501

        self._permit_alteration_reference_number = permit_alteration_reference_number

    @property
    def date_created(self):
        """Gets the date_created of this PermitAlterationSummaryResponse.  # noqa: E501


        :return: The date_created of this PermitAlterationSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this PermitAlterationSummaryResponse.


        :param date_created: The date_created of this PermitAlterationSummaryResponse.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def deadline_date(self):
        """Gets the deadline_date of this PermitAlterationSummaryResponse.  # noqa: E501


        :return: The deadline_date of this PermitAlterationSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._deadline_date

    @deadline_date.setter
    def deadline_date(self, deadline_date):
        """Sets the deadline_date of this PermitAlterationSummaryResponse.


        :param deadline_date: The deadline_date of this PermitAlterationSummaryResponse.  # noqa: E501
        :type: datetime
        """
        if deadline_date is None:
            raise ValueError("Invalid value for `deadline_date`, must not be `None`")  # noqa: E501

        self._deadline_date = deadline_date

    @property
    def alteration_status(self):
        """Gets the alteration_status of this PermitAlterationSummaryResponse.  # noqa: E501


        :return: The alteration_status of this PermitAlterationSummaryResponse.  # noqa: E501
        :rtype: AlterationStatusResponse
        """
        return self._alteration_status

    @alteration_status.setter
    def alteration_status(self, alteration_status):
        """Sets the alteration_status of this PermitAlterationSummaryResponse.


        :param alteration_status: The alteration_status of this PermitAlterationSummaryResponse.  # noqa: E501
        :type: AlterationStatusResponse
        """
        if alteration_status is None:
            raise ValueError("Invalid value for `alteration_status`, must not be `None`")  # noqa: E501

        self._alteration_status = alteration_status

    @property
    def alteration_status_string(self):
        """Gets the alteration_status_string of this PermitAlterationSummaryResponse.  # noqa: E501


        :return: The alteration_status_string of this PermitAlterationSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._alteration_status_string

    @alteration_status_string.setter
    def alteration_status_string(self, alteration_status_string):
        """Sets the alteration_status_string of this PermitAlterationSummaryResponse.


        :param alteration_status_string: The alteration_status_string of this PermitAlterationSummaryResponse.  # noqa: E501
        :type: str
        """
        if alteration_status_string is None:
            raise ValueError("Invalid value for `alteration_status_string`, must not be `None`")  # noqa: E501

        self._alteration_status_string = alteration_status_string

    @property
    def alteration_type(self):
        """Gets the alteration_type of this PermitAlterationSummaryResponse.  # noqa: E501


        :return: The alteration_type of this PermitAlterationSummaryResponse.  # noqa: E501
        :rtype: AlterationTypeResponse
        """
        return self._alteration_type

    @alteration_type.setter
    def alteration_type(self, alteration_type):
        """Sets the alteration_type of this PermitAlterationSummaryResponse.


        :param alteration_type: The alteration_type of this PermitAlterationSummaryResponse.  # noqa: E501
        :type: AlterationTypeResponse
        """
        if alteration_type is None:
            raise ValueError("Invalid value for `alteration_type`, must not be `None`")  # noqa: E501

        self._alteration_type = alteration_type

    @property
    def alteration_type_string(self):
        """Gets the alteration_type_string of this PermitAlterationSummaryResponse.  # noqa: E501


        :return: The alteration_type_string of this PermitAlterationSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._alteration_type_string

    @alteration_type_string.setter
    def alteration_type_string(self, alteration_type_string):
        """Sets the alteration_type_string of this PermitAlterationSummaryResponse.


        :param alteration_type_string: The alteration_type_string of this PermitAlterationSummaryResponse.  # noqa: E501
        :type: str
        """
        if alteration_type_string is None:
            raise ValueError("Invalid value for `alteration_type_string`, must not be `None`")  # noqa: E501

        self._alteration_type_string = alteration_type_string

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PermitAlterationSummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PermitAlterationSummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
